@@ -15,7 +15,11 @@
 #endif
 
 int have_voms = 0;
-void (*get_voms_proxy_impl)();
+void (*get_voms_proxy_impl)(myproxy_socket_attrs_t *,
+                            myproxy_creds_t *,
+                            myproxy_request_t *,
+                            myproxy_response_t *,
+                            myproxy_server_context_t *);
 
 static char usage[] = \
 "\n"\
@@ -287,10 +291,17 @@ main(int argc, char *argv[])
     }
 
     if(server_context->certificate_openssl_engine_id) {
+#ifndef OPENSSL_NO_ENGINE
         if(!initialise_openssl_engine(server_context)) {
             myproxy_log_verror();
             my_failure("Could not initialise OpenSSL engine.");
         }
+#else
+        myproxy_log("Openssl has no engine support.");
+        myproxy_log("Can not use certificate_openssl_engine_id option.");
+        myproxy_log("Exiting.");
+        exit(1);
+#endif
     }
 
     if (!server_context->run_as_daemon) {
